<?php

namespace Techza\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use Elementor\Widget_Base;

if ( !defined( 'ABSPATH' ) ) {

    exit;

}

/**

 * Elementor oEmbed Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class Main_Menu extends Widget_Base {

    /**

     * Get widget name.

     *

     * Retrieve oEmbed widget name.

     *

     * @since 1.0.0

     * @access public

     *

     * @return string Widget name.

     */

    public function get_name() {

        return 'techza-main-menu';

    }

    /**

     * Get widget title.

     *

     * Retrieve oEmbed widget title.

     *

     * @since 1.0.0

     * @access public

     *

     * @return string Widget title.

     */

    public function get_title() {

        return __( 'Primary Menu', 'techza-hp' );

    }

    /**

     * Get widget icon.

     *

     * Retrieve oEmbed widget icon.

     *

     * @since 1.0.0

     * @access public

     *

     * @return string Widget icon.

     */

    public function get_icon() {

        return 'eicon-nav-menu';

    }

    /**

     * Get widget categories.

     *

     * Retrieve the list of categories the oEmbed widget belongs to.

     *

     * @since 1.0.0

     * @access public

     *

     * @return array Widget categories.

     */

    public function get_categories() {

        return ['techza-addons'];

    }

    /**

     * Retrieve the list of available menus.

     *

     * Used to get the list of available menus.

     *

     * @since 1.3.0

     * @access private

     *

     * @return array get WordPress menus list.

     */

    private function get_available_menus() {

        $menus = wp_get_nav_menus();

        $options = [];

        foreach ( $menus as $menu ) {

            $options[$menu->slug] = $menu->name;

        }

        return $options;

    }

    /**

     * Register oEmbed widget controls.

     *

     * Adds different input fields to allow the user to change and customize the widget settings.

     *

     * @since 1.0.0

     * @access protected

     */

    protected function register_controls() {

        /**

         * Style tab

         */

        $this->start_controls_section(
            'section_layout',
            [
                'label' => __( 'Layout', 'techza-hp' ),
            ]
        );

        $this->add_control(
            'logo_type',
            [
                'label'   => __( 'Logo Type', 'techza-hp' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dark',
                'options' => [
                    'dark'   => __( 'Dark', 'techza-hp' ),
                    'white'  => __( 'White', 'techza-hp' ),
                    'custom' => __( 'Custom', 'techza-hp' ),
                ],
            ]
        );

        $this->add_control(
            'image',
            [
                'label'     => __( 'Choose logo', 'techza-hp' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'default'   => [
                    'url' => '',
                ],
                'condition' => [
                    'logo_type' => 'custom',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'      => 'logo_size',
                'exclude'   => ['custom'],
                'include'   => [],
                'default'   => 'large',
                'condition' => [
                    'logo_type' => 'custom',
                ],
            ]
        );

        $this->add_responsive_control(
            'image_width',
            [
                'label'     => __( 'Image width', 'techza-hp' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'devices'   => ['mobile'],
                'selectors' => [
                    '{{WRAPPER}} .site-branding.mobile-version.has-site-logo img' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(

            'general',

            [

                'label' => __( 'Content', 'techza-hp' ),

                'tab'   => Controls_Manager::TAB_CONTENT,

            ]

        );

        $this->add_control(

            'use_main_menu',

            [

                'label'        => __( 'Use Main Menu', 'techza-hp' ),

                'type'         => Controls_Manager::SWITCHER,

                'label_on'     => __( 'Yes', 'techza-hp' ),

                'label_off'    => __( 'No', 'techza-hp' ),

                'return_value' => 'yes',

                'default'      => 'yes',

            ]

        );

        $menus = $this->get_available_menus();

        if ( !empty( $menus ) ) {

            $this->add_control(

                'primary_menu',

                [

                    'label'        => __( 'Menu', 'header-footer-elementor' ),

                    'type'         => Controls_Manager::SELECT,

                    'options'      => $menus,

                    'default'      => array_keys( $menus )[0],

                    'save_default' => true,

                    'separator'    => 'after',

                    /* translators: %s Nav menu URL */

                    'description'  => sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'header-footer-elementor' ), admin_url( 'nav-menus.php' ) ),

                    'condition'    => [

                        'use_main_menu!' => 'yes',

                    ],

                ]

            );

        } else {

            $this->add_control(

                'menu',

                [

                    'type'            => Controls_Manager::RAW_HTML,

                    /* translators: %s Nav menu URL */

                    'raw'             => sprintf( __( '<strong>There are no menus in your site.</strong><br>Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'header-footer-elementor' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),

                    'separator'       => 'after',

                    'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',

                ]

            );

        }

        $this->add_control(

            'menu_style',

            [

                'label'   => __( 'Border Style', 'techza-hp' ),

                'type'    => Controls_Manager::SELECT,

                'default' => 'inline',

                'options' => [

                    'inline' => __( 'Inline', 'techza-hp' ),

                    'flyout' => __( 'Flyout', 'techza-hp' ),

                ],

            ]

        );

        $this->add_control(

            'trigger_label',

            [

                'label' => __( 'Trigger Label', 'techza-hp' ),

                'type'  => Controls_Manager::TEXT,

            ]

        );

        $this->add_control(

            'trigger_open_icon',

            [

                'label'   => __( 'Trigger Icon', 'techza-hp' ),

                'type'    => Controls_Manager::ICONS,

                'default' => [

                    'value'   => 'fa fa-align-justify',

                    'library' => 'solid',

                ],

            ]

        );

        $this->add_control(

            'trigger_close_icon',

            [

                'label'   => __( 'Trigger Close Icon', 'techza-hp' ),

                'type'    => Controls_Manager::ICONS,

                'default' => [

                    'value'   => 'far fa-window-close',

                    'library' => 'solid',

                ],

            ]

        );

        $this->add_responsive_control(

            'menu_align',
            [
                'label'     => __( 'Align', 'techza-hp' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'start'    => [
                        'title' => __( 'Left', 'techza-hp' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center'   => [
                        'title' => __( 'top', 'techza-hp' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'flex-end' => [
                        'title' => __( 'Right', 'techza-hp' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'default'   => 'left',
                'toggle'    => true,
                'selectors' => [
                    '{{WRAPPER}} .navbar' => 'justify-content: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'button1',
            [
                'label' => __( 'Header Buttons', 'techza-hp' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_responsive_control(
            'button_align',
            [
                'label'     => esc_html__( 'Dual Button Align', 'plugin-name' ),
                'type'      => \Elementor\Controls_Manager::CHOOSE,
                'options'   => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'plugin-name' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center'     => [
                        'title' => esc_html__( 'Center', 'plugin-name' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'flex-end'   => [
                        'title' => esc_html__( 'Right', 'plugin-name' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'default'   => 'flex-end',
                'toggle'    => true,
                'selectors' => [
                    '{{WRAPPER}} .techza-main-menu-wrap .techza-header-buttons' => 'justify-content: {{VALUE}}',

                ],
            ]
        );

        $this->start_controls_tabs( 'techza_dual_button_content_tabs' );
        $this->start_controls_tab(
            'techza_dual_button_primary_button_content',
            [
                'label' => esc_html__( 'Primary', 'techza' ),
            ]
        );
        $this->add_control(
            'enable_primary_btn',
            [
                'label'        => __( 'Enable Primary Button?', 'techza-hp' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'techza-hp' ),
                'label_off'    => __( 'No', 'techza-hp' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );
        $this->add_control(
            'techza_dual_button_primary_button_text',
            [
                'label'       => esc_html__( 'Text', 'techza' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'VIEW DEMO', 'techza' ),
                'dynamic'     => [
                    'active' => true,
                ],
                'condition'   => [
                    'enable_primary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_primary_button_url',
            [
                'label'         => esc_html__( 'Link', 'techza' ),
                'type'          => Controls_Manager::URL,
                'label_block'   => true,
                'placeholder'   => __( 'https://your-link.com', 'techza' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '#',
                    'is_external' => true,
                ],
                'condition'     => [
                    'enable_primary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_primary_button_icon',
            [
                'label'     => esc_html__( 'Icon', 'techza' ),
                'type'      => Controls_Manager::ICONS,
                'condition' => [
                    'enable_primary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_primary_button_icon_position',
            [
                'label'     => __( 'Icon Position', 'techza' ),
                'type'      => Controls_Manager::CHOOSE,
                'toggle'    => false,
                'options'   => [
                    'techza-icon-pos-left'  => [
                        'title' => __( 'Left', 'techza' ),
                        'icon'  => 'eicon-angle-left',
                    ],
                    'techza-icon-pos-right' => [
                        'title' => __( 'Right', 'techza' ),
                        'icon'  => 'eicon-angle-right',
                    ],
                ],
                'default'   => 'techza-icon-pos-left',
                'condition' => [
                    'enable_primary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'techza_dual_button_secondary_button_content',
            [
                'label' => esc_html__( 'Secondary', 'techza' ),

            ]
        );

        $this->add_control(
            'enable_secondary_btn',
            [
                'label'        => __( 'Enable Secondary Button?', 'techza-hp' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'techza-hp' ),
                'label_off'    => __( 'No', 'techza-hp' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'techza_dual_button_secondary_button_text',
            [
                'label'       => esc_html__( 'Text', 'techza' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'ORDER NOW', 'techza' ),
                'dynamic'     => [
                    'active' => true,
                ],
                'condition'   => [
                    'enable_secondary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_secondary_button_url',
            [
                'label'         => esc_html__( 'Link', 'techza' ),
                'type'          => Controls_Manager::URL,
                'label_block'   => true,
                'placeholder'   => __( 'https://your-link.com', 'techza' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '#',
                    'is_external' => true,
                ],
                'condition'     => [
                    'enable_secondary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_secondary_button_icon',
            [
                'label' => esc_html__( 'Icon', 'techza' ),
                'type'  => Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'techza_dual_button_secondary_button_icon_position',
            [
                'label'     => __( 'Icon Position', 'techza' ),
                'type'      => Controls_Manager::CHOOSE,
                'toggle'    => false,
                'options'   => [
                    'techza-icon-pos-left'  => [
                        'title' => __( 'Left', 'techza' ),
                        'icon'  => 'eicon-angle-left',
                    ],
                    'techza-icon-pos-right' => [
                        'title' => __( 'Right', 'techza' ),
                        'icon'  => 'eicon-angle-right',
                    ],
                ],
                'default'   => 'techza-icon-pos-left',
                'condition' => [
                    'enable_secondary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(

            'header_infos_section',

            [

                'label'     => __( 'Header Info', 'techza-hp' ),

                'tab'       => Controls_Manager::TAB_CONTENT,

                'condition' => [

                    'menu_style' => 'flyout',

                ],

            ]

        );

        $this->add_control(

            'show_infos',

            [

                'label'        => __( 'Show Title', 'techza-hp' ),

                'type'         => Controls_Manager::SWITCHER,

                'label_on'     => __( 'Show', 'techza-hp' ),

                'label_off'    => __( 'Hide', 'techza-hp' ),

                'return_value' => 'yes',

                'default'      => 'no',

                'condition'    => [

                    'menu_style' => 'flyout',

                ],

            ]

        );

        $repeater = new Repeater();

        $repeater->add_control(

            'info_title',

            [

                'label'       => __( 'Title', 'techza-hp' ),

                'type'        => Controls_Manager::TEXT,

                'default'     => __( 'info Title', 'techza-hp' ),

                'label_block' => true,

            ]

        );

        $repeater->add_control(

            'info_content',

            [

                'label'      => __( 'Content', 'techza-hp' ),

                'type'       => Controls_Manager::WYSIWYG,

                'default'    => __( 'info Content', 'techza-hp' ),

                'show_label' => false,

            ]

        );

        $repeater->add_control(

            'info_url',

            [

                'label'         => __( 'Link', 'techza-hp' ),

                'type'          => Controls_Manager::URL,

                'placeholder'   => __( 'https://your-link.com', 'techza-hp' ),

                'show_external' => true,

            ]

        );

        $this->add_control(

            'header_infos',

            [

                'label'       => __( 'Repeater info', 'techza-hp' ),

                'type'        => Controls_Manager::REPEATER,

                'fields'      => $repeater->get_controls(),

                'default'     => [

                    [

                        'info_title'   => __( 'Call us:', 'techza-hp' ),

                        'info_content' => __( '(234) 567 8901', 'techza-hp' ),

                    ],

                ],

                'title_field' => '{{{ info_title }}}',

                'condition'   => [

                    'show_infos' => 'yes',

                ],

            ]

        );

        $this->end_controls_section();

        $this->start_controls_section(

            'section_menu_style',

            [

                'label'     => __( 'Menu Style', 'techza-hp' ),

                'tab'       => Controls_Manager::TAB_STYLE,

                'condition' => [

                    'menu_style' => 'inline',

                ],

            ]

        );

        $this->start_controls_tabs(

            'menu_items_tabs'

        );

        $this->start_controls_tab(

            'menu_normal_tab',

            [

                'label' => __( 'Normal', 'techza-hp' ),

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'menu_typography',

                'label'    => __( 'Menu Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .main-navigation ul.navbar-nav>li>a',

            ]

        );

        $this->add_control(

            'menu_color',

            [

                'label'     => __( 'Item Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav>li>a,

                     {{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav > .menu-item-has-children > a .dropdownToggle' => 'color: {{VALUE}}',

                    '{{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav > .menu-item-has-children > a  .dropdownToggle'                    => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'menu_bg_color',

            [

                'label'     => __( 'Item Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav>li>a' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_responsive_control(

            'item_gap',

            [

                'label'     => __( 'Menu Gap', 'techza-hp' ),

                'type'      => Controls_Manager::SLIDER,

                'range'     => [

                    'px' => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'devices'   => ['desktop', 'tablet', 'mobile'],

                'selectors' => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li>a' => 'margin-left: {{SIZE}}{{UNIT}};margin-right: {{SIZE}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li>a'       => 'margin-right: {{SIZE}}{{UNIT}};margin-right: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'item_padding',

            [

                'label'      => __( 'Item Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li>a'                      => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>.menu-item-has-children>a' => 'padding: {{TOP}}{{UNIT}} calc({{RIGHT}}{{UNIT}} + 20px) {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li>a'                            => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>.menu-item-has-children>a'       => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} calc({{RIGHT}}{{UNIT}} + 20px);',

                ],

            ]

        );

        $this->add_responsive_control(

            'item_readius',

            [

                'label'      => __( 'Item Radius', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li>a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li>a'       => 'border-radius: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'menu_hover_tab',

            [

                'label' => __( 'Hover', 'techza-hp' ),

            ]

        );

        $this->add_control(

            'menu_hover_color',

            [

                'label'     => __( 'Menu Hover Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav>li>a:hover,

                     {{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav > .menu-item-has-children > a:hover .dropdownToggle,

                     {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav li.current-menu-item>a'                                 => 'color: {{VALUE}}',

                    '{{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .sub-menu:not(.techza-megamenu-builder-content-wrap) a .menu-item-text:after' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'menu_bg_hover_color',

            [

                'label'     => __( 'Item Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav>li:hover>a' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(

            'dropdown_style',

            [

                'label'     => __( 'Dropdown Style', 'techza-hp' ),

                'tab'       => Controls_Manager::TAB_STYLE,

                'condition' => [

                    'menu_style' => 'inline',

                ],

            ]

        );

        $this->start_controls_tabs(

            'dropdown_items_tabs'

        );

        $this->start_controls_tab(

            'dropdown_normal_tab',

            [

                'label' => __( 'Normal', 'techza-hp' ),

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'dripdown_typography',

                'label'    => __( 'Menu Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>li .sub-menu:not(.techza-megamenu-builder-content-wrap) a',

            ]

        );

        $this->add_control(

            'dropdown_item_color',

            [

                'label'     => __( 'Item Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a,

                        {{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav .sub-menu .menu-item-has-children > a  .dropdownToggle' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'dropdown_item_bg_color',

            [

                'label'     => __( 'Item Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'ddown_menu_border_color',

            [

                'label'     => __( 'Menu Border Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu,

                    {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:before' => 'border-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_responsive_control(

            'dropdown_item_radius',

            [

                'label'      => __( 'Menu radius', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}}  .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu'      => 'border-radius: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'dropdown_item_padding',

            [

                'label'      => __( 'Item Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a'       => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'dropdown_padding',

            [

                'label'      => __( 'Menu Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav>.menu-item-has-children:not(.techza-mega-menu) .sub-menu' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'dropdown_hover_tab',

            [

                'label' => __( 'Hover', 'techza-hp' ),

            ]

        );

        $this->add_control(

            'dropdown_item_hover_color',

            [

                'label'     => __( 'Item Hover Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a:hover, {{WRAPPER}} .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) li.current-menu-item> a,

                     {{WRAPPER}} .menu-style-inline.navbar:not(.active) .main-navigation ul.navbar-nav .sub-menu .menu-item-has-children > a:hover  .dropdownToggle' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'dropdown_item_bg_hover_color',

            [

                'label'     => __( 'Item Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-inline .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a:hover, {{WRAPPER}} .main-navigation ul.navbar-nav .sub-menu li.current-menu-item>a' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(

            'section_flyout_style',

            [

                'label' => __( 'Flyout/Mobile Menu Style', 'techza-hp' ),

                'tab'   => Controls_Manager::TAB_STYLE,

            ]

        );

        $this->start_controls_tabs(

            'flyout_items_tabs'

        );

        $this->start_controls_tab(

            'flyout_menu_normal_tab',

            [

                'label' => __( 'Normal', 'techza-hp' ),

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'flyout_menu_typography',

                'label'    => __( 'Item Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>li>a',

            ]

        );

        $this->add_control(

            'flyout_menu_color',

            [

                'label'     => __( 'Item Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>li>a,
                     {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav > .menu-item-has-children > a .dropdownToggle' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav > .menu-item-has-children > a  .dropdownToggle'                    => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_responsive_control(

            'flyout_item_padding',

            [

                'label'      => __( 'Item Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>li>a'                      => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body:not(.rtl) {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>.menu-item-has-children>a' => 'padding: {{TOP}}{{UNIT}} calc({{RIGHT}}{{UNIT}} + 20px) {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>li>a'                            => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>.menu-item-has-children>a'       => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} calc({{RIGHT}}{{UNIT}} + 20px);',

                ],

            ]

        );

        $this->add_responsive_control(

            'flyout_menu_padding',

            [

                'label'      => __( 'Menu Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-flyout .main-navigation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-flyout .main-navigation'       => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'flyout_menu_hover_tab',

            [

                'label' => __( 'Hover', 'techza-hp' ),

            ]

        );

        // $this->add_control(

        //     'flyout_menu_hover_color',

        //     [

        //         'label'     => __( 'Menu Hover Color', 'techza-hp' ),

        //         'type'      => Controls_Manager::COLOR,

        //         'selectors' => [
        //             '{{WRAPPER}} .menu-style-flyout .menu-style-flyout .main-navigation ul.navbar-nav>li>a:hover,
        //              {{WRAPPER}} .menu-style-flyout .menu-style-flyout .main-navigation ul.navbar-nav > .menu-item-has-children > a:hover .dropdownToggle,
        //              {{WRAPPER}} .menu-style-flyout .menu-style-flyout .main-navigation ul.navbar-nav li.current-menu-item>a' => 'color: {{VALUE}}',
        //         ],

        //     ]

        // );

        $this->add_control(

            'flyout_menu_hover_color',

            [

                'label'     => __( 'Menu Hover Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [
                    '{{WRAPPER}} .menu-style-flyout .menu-style-flyout .main-navigation ul.navbar-nav>li> a:hover,
                     {{WRAPPER}} .menu-style-flyout .menu-style-flyout .main-navigation ul.navbar-nav > .menu-item-has-children > a:hover .dropdownToggle,
                     {{WRAPPER}} .menu-style-flyout .menu-style-flyout .main-navigation ul.navbar-nav li.current-menu-item>a' => 'color: {{VALUE}}',
                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(

            'flyout_dropdown_style',

            [

                'label' => __( 'Flyout/Mobile Dropdown Style', 'techza-hp' ),

                'tab'   => Controls_Manager::TAB_STYLE,

            ]

        );

        $this->start_controls_tabs(

            'flyout_dropdown_items_tabs'

        );

        $this->start_controls_tab(

            'flyout_dropdown_normal_tab',

            [

                'label' => __( 'Normal', 'techza-hp' ),

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'flyout_dripdown_typography',

                'label'    => __( 'Dropdown Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>li .sub-menu:not(.techza-megamenu-builder-content-wrap) a',

            ]

        );

        $this->add_control(

            'flyout_dropdown_item_color',

            [

                'label'     => __( 'Item Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a,

                        {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav>li .sub-menu .dropdownToggle' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'flyout_dropdown_item_bg_color',

            [

                'label'     => __( 'Item Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_responsive_control(

            'flyout_dropdown_item_padding',

            [

                'label'      => __( 'Item Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    'body:not(.rtl) {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a'       => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'flyout_dropdown_hover_tab',

            [

                'label' => __( 'Hover', 'techza-hp' ),

            ]

        );

        $this->add_control(

            'flyout_dropdown_item_hover_color',

            [

                'label'     => __( 'Item Hover Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a:hover,

                     {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .sub-menu .menu-item-has-children > a:hover  .dropdownToggle' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'flyout_dropdown_item_bg_hover_color',

            [

                'label'     => __( 'Item Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) a:hover,

                    {{WRAPPER}} .menu-style-flyout .main-navigation ul.navbar-nav .menu-item-has-children .sub-menu:not(.techza-megamenu-builder-content-wrap) .sub-menu li.current-menu-item>a' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(

            'trigger_style',

            [

                'label' => __( 'Trigger Style', 'techza-hp' ),

                'tab'   => Controls_Manager::TAB_STYLE,

            ]

        );

        $this->start_controls_tabs(

            'trigger_style_tabs'

        );

        $this->start_controls_tab(

            'trigger_style_normal_tab',

            [

                'label' => __( 'Normal', 'techza-hp' ),

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'trigger_typography',

                'label'    => __( 'Trigger Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .navbar-toggler.open-menu',

            ]

        );

        $this->add_control(

            'trigger_color',

            [

                'label'     => __( 'Trigger Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar-toggler.open-menu,{{WRAPPER}} .navbar-toggler.open-menu .navbar-toggler-icon'         => 'color: {{VALUE}}',

                    '{{WRAPPER}} .navbar-toggler.open-menu svg,{{WRAPPER}} .navbar-toggler.open-menu .navbar-toggler-icon svg' => 'fill: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'trigger_background',

            [

                'label'     => __( 'Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar-toggler.open-menu' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_group_control(

            Group_Control_Border::get_type(),

            [

                'name'     => 'trigger_border',

                'label'    => __( 'Border', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .navbar-toggler.open-menu',

            ]

        );

        $this->add_control(

            'trigger_icon_size',

            [

                'label'      => __( 'Icon size', 'plugin-domain' ),

                'type'       => Controls_Manager::SLIDER,

                'size_units' => ['px', '%'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .navbar-toggler.open-menu .navbar-toggler-icon svg'  => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .navbar-toggler.close-menu .navbar-toggler-icon svg' => 'width: {{SIZE}}{{UNIT}};',

                    '{{WRAPPER}} .navbar-toggler.open-menu .navbar-toggler-icon i'    => 'font-size: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'trigger_icon_gap',

            [

                'label'      => __( 'Icon Gap', 'plugin-domain' ),

                'type'       => Controls_Manager::SLIDER,

                'size_units' => ['px', '%'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .navbar-toggler.open-menu .navbar-toggler-icon' => 'margin-right: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'trigger_radius',

            [

                'label'      => __( 'Border Radius', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .navbar-toggler.open-menu'          => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .navbar-toggler.open-menu' => 'border-radius: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}}

                    ;',

                ],

            ]

        );

        $this->add_responsive_control(

            'trigger_padding',

            [

                'label'      => __( 'Button Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .navbar-toggler.open-menu'          => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .navbar-toggler.open-menu' => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'trigger_style_hover_tab',

            [

                'label' => __( 'Hover', 'techza-hp' ),

            ]

        );

        $this->add_control(

            'trigger_hover_color',

            [

                'label'     => __( 'Trigger Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar-toggler.open-menu:hover' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'trigger_hover_background',

            [

                'label'     => __( 'Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar-toggler.open-menu:hover' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_group_control(

            Group_Control_Border::get_type(),

            [

                'name'     => 'trigger_hover_border',

                'label'    => __( 'Border', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .navbar-toggler.open-menu:hover',

            ]

        );

        $this->add_control(

            'trigger_hover_animation',

            [

                'label' => __( 'Hover Animation', 'techza-hp' ),

                'type'  => Controls_Manager::HOVER_ANIMATION,

            ]

        );

        $this->add_responsive_control(

            'trigger_hover_radius',

            [

                'label'      => __( 'Border Radius', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .navbar-toggler.open-menu:hover'          => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .navbar-toggler.open-menu:hover' => 'border-radius: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}}

                    ;',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(

            'infos_style_section',

            [

                'label'     => __( 'Info Style', 'techza-hp' ),

                'tab'       => Controls_Manager::TAB_STYLE,

                'condition' => [

                    'show_infos' => 'yes',

                ],

            ]

        );

        $this->start_controls_tabs(

            'info_style_tabs'

        );

        $this->start_controls_tab(

            'info_style_normal_tab',

            [

                'label' => __( 'Normal', 'techza-hp' ),

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'info_title_typography',

                'label'    => __( 'Title Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .header-info span',

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'info_typography',

                'label'    => __( 'Info Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .header-info h3 ',

            ]

        );

        $this->add_control(

            'info_title_color',

            [

                'label'     => __( 'Info Title Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .header-info span' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'info_color',

            [

                'label'     => __( 'Info Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}}  .header-info h3' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_group_control(

            Group_Control_Border::get_type(),

            [

                'name'     => 'info_box_border',

                'label'    => __( 'Box Border', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .techza-header-infos',

            ]

        );

        $this->add_control(

            'info_title_gap',

            [

                'label'      => __( 'Info Title Gap', 'plugin-domain' ),

                'type'       => Controls_Manager::SLIDER,

                'size_units' => ['px', '%'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .header-info span' => 'margin-bottom: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'ifno_item_padding',

            [

                'label'      => __( 'Info item Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .header-info'          => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .header-info' => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'info_style_hover_tab',

            [

                'label' => __( 'Hover', 'techza-hp' ),

            ]

        );

        $this->add_control(

            'info_title_color_hover',

            [

                'label'     => __( 'Info Title Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .header-info:hover span' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'info_color_hover',

            [

                'label'     => __( 'Info Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}}  .header-info:hover h3' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(

            'panel_style',

            [

                'label' => __( 'Panel Style', 'techza-hp' ),

                'tab'   => Controls_Manager::TAB_STYLE,

            ]

        );

        $this->add_group_control(

            Group_Control_Typography::get_type(),

            [

                'name'     => 'panel_label_typography',

                'label'    => __( 'Label Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .menu-style-flyout .navbar-inner .navbar-toggler',

            ]

        );

        $this->add_control(

            'panel_label_color',

            [

                'label'     => __( 'Label Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .navbar-inner .navbar-toggler' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'close_trigger_color',

            [

                'label'     => __( 'Close Trigger Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .navbar-inner .navbar-toggler i'        => 'color: {{VALUE}}',

                    '{{WRAPPER}} .menu-style-flyout .navbar-inner .navbar-toggler svg path' => 'stroke: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'close_trigger_fill_color',

            [

                'label'     => __( 'Close Trigger Fill Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .navbar-inner .navbar-toggler svg path' => 'fill: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'close_label_background',

            [

                'label'     => __( 'Label Background Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar-toggler.close-menu' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'panel_background',

            [

                'label'     => __( 'Panel Color', 'techza-hp' ),

                'type'      => Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .menu-style-flyout .navbar-inner' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'trigger_cloxe_icon_size',

            [

                'label'      => __( 'Close Icon size', 'plugin-domain' ),

                'type'       => Controls_Manager::SLIDER,

                'size_units' => ['px', '%'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .menu-style-flyout .navbar-toggler.close-menu .navbar-toggler-icon svg' => 'width: {{SIZE}}{{UNIT}};',

                    '{{WRAPPER}} .menu-style-flyout .navbar-toggler.close-menu .navbar-toggler-icon i'   => 'font-size: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_group_control(

            Group_Control_Box_Shadow::get_type(),

            [

                'name'     => 'panel_shadow',

                'label'    => __( 'Panel Shadow', 'techza-hp' ),

                'selector' => '{{WRAPPER}}  .navbar-inner',

            ]

        );

        $this->add_responsive_control(

            'close_label_padding',

            [

                'label'      => __( 'Label Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}}  .menu-style-flyout .navbar-toggler.close-menu' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}}  .navbar-toggler.close-menu'           => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'panel_padding',

            [

                'label'      => __( 'Panel Padding', 'techza-hp' ),

                'type'       => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .menu-style-flyout .navbar-inner'           => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                    'body.rtl {{WRAPPER}} .menu-style-flyout  .navbar-inner' => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',

                ],

            ]

        );

        $this->end_controls_section();

        $this->start_controls_section(

            'megamenu_style',

            [

                'label' => __( 'Megamenu Settings', 'techza-hp' ),

                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

            ]

        );

        $this->start_controls_tabs(

            'megamenu_items_tabs'

        );

        $this->start_controls_tab(

            'megamenu_normal_tab',

            [

                'label' => __( 'Normal', 'plugin-name' ),

            ]

        );

        $this->add_group_control(

            \Elementor\Group_Control_Typography::get_type(),

            [

                'name'     => 'megamenu_title_typography',

                'label'    => __( 'Heading Typography', 'techza-hp' ),

                'selector' => '{{WRAPPER}} .navbar:not(.active) .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu>li.megamenu-heading>a',

            ]

        );

        $this->add_control(

            'megamenu_title_color',

            [

                'label'     => __( 'Heading Color', 'techza-hp' ),

                'type'      => \Elementor\Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar:not(.active) .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu>li.megamenu-heading>a' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'mega_menu_bg_color',

            [

                'label'     => __( 'Menu Background Color', 'techza-hp' ),

                'type'      => \Elementor\Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar:not(.active) .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu' => 'background-color: {{VALUE}}',

                ],

            ]

        );

        $this->add_control(

            'column_width',

            [

                'label'      => __( 'Column Width', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::SLIDER,

                'size_units' => ['px', '%'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 2000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu>li' => 'width: {{SIZE}}{{UNIT}}!important;',

                ],

            ]

        );

        $this->add_control(

            'megamenu_width_type',

            [

                'label'   => __( 'Menu Width', 'techza-hp' ),

                'type'    => \Elementor\Controls_Manager::SELECT,

                'default' => 'custom',

                'options' => [

                    'container' => __( 'Container', 'techza-hp' ),

                    'custom'    => __( 'custom', 'techza-hp' ),

                ],

            ]

        );

        $this->add_control(

            'megamenu_panel_width',

            [

                'label'      => __( 'Menu Width', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::SLIDER,

                'size_units' => ['px', '%', 'vw'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu' => 'width: {{SIZE}}{{UNIT}};',

                ],

                'condition'  => [

                    'megamenu_width_type' => 'custom',

                ],

            ]

        );

        $this->add_responsive_control(

            'megamenu_builder_width',

            [

                'label'      => __( 'Megamenu Builder Content Width', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::SLIDER,

                'size_units' => ['px', '%', 'vw'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .main-navigation ul.navbar-nav>li.techza-megamenu-builder-parent>ul.techza-megamenu-builder-content-wrap.sub-menu' => 'width: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'megamenu_builder_margin',

            [

                'label'      => __( 'Megamenu Builder Margin', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .main-navigation ul.navbar-nav>li.techza-megamenu-builder-parent>ul.techza-megamenu-builder-content-wrap.sub-menu' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;',

                ],

            ]

        );

        $this->add_responsive_control(

            'megamenu_padding',

            [

                'label'      => __( 'Menu Padding', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::DIMENSIONS,

                'size_units' => ['px', 'em', '%'],

                'selectors'  => [

                    '{{WRAPPER}} .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->start_controls_tab(

            'megamenu_hover_tab',

            [

                'label' => __( 'Hover', 'plugin-name' ),

            ]

        );

        $this->add_control(

            'megamenu_title_color_hover',

            [

                'label'     => __( 'Heading Color', 'techza-hp' ),

                'type'      => \Elementor\Controls_Manager::COLOR,

                'selectors' => [

                    '{{WRAPPER}} .navbar:not(.active) .main-navigation ul.navbar-nav>li.techza-mega-menu>.sub-menu>li.megamenu-heading>a:hover' => 'color: {{VALUE}}',

                ],

            ]

        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

/*
 * Finest Base Dual Button Primary Button Style
 */
        $this->start_controls_section(
            'techza_container_primary_button_style',
            [
                'label'     => esc_html__( 'Primary Button', 'techza' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'enable_primary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->add_responsive_control(

            'praimary_button_width',

            [

                'label'      => __( 'Button Width', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::SLIDER,

                'size_units' => ['px', '%', 'vw'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .techza-dual-button-primary' => 'width: {{SIZE}}{{UNIT}};',

                ],

            ]

        );
        $this->add_responsive_control(

            'praimary_button_height',

            [

                'label'      => __( 'Button Height', 'techza-hp' ),

                'type'       => \Elementor\Controls_Manager::SLIDER,

                'size_units' => ['px', '%', 'vw'],

                'range'      => [

                    'px' => [

                        'min' => 0,

                        'max' => 1000,

                    ],

                    '%'  => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'selectors'  => [

                    '{{WRAPPER}} .techza-dual-button-primary' => 'height: {{SIZE}}{{UNIT}};',

                ],

            ]

        );
        $this->start_controls_tabs( 'techza_dual_button_primary_button_tabs' );
        $this->start_controls_tab( 'techza_dual_button_primary_button_noemal', ['label' => esc_html__( 'Normal', 'techza' )] );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'techza_container_primary_button_typography',
                'selector' => '{{WRAPPER}} .techza-dual-button-primary span',
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_primary_button_icon_margin',
            [
                'label'      => __( 'Icon Space', 'techza' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 3,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 10,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-primary .techza-icon-pos-left i'  => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .techza-dual-button-primary .techza-icon-pos-right i' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'techza_dual_button_primary_button_icon[value]!' => '',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_container_primary_button_padding',
            [
                'label'      => __( 'Padding', 'techza' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'default'    => [
                    'top'      => '',
                    'right'    => '',
                    'bottom'   => '',
                    'left'     => '',
                    'unit'     => 'px',
                    'isLinked' => false,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-primary' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_container_primary_button_margin',
            [
                'label'      => __( 'Margin', 'techza' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'default'    => [
                    'top'      => '',
                    'right'    => '',
                    'bottom'   => '',
                    'left'     => '',
                    'unit'     => 'px',
                    'isLinked' => false,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-primary' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_primary_button_radius',
            [
                'label'      => __( 'Border radius', 'techza' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'default'    => [
                    'top'    => '3',
                    'right'  => '3',
                    'bottom' => '3',
                    'left'   => '3',
                    'unit'   => 'px',
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-primary,
                            {{WRAPPER}} .techza-dual-button-primary.effect-1::before,
                            {{WRAPPER}} .techza-dual-button-primary.effect-2::before,
                            {{WRAPPER}} .techza-dual-button-primary.effect-3::before,
                            {{WRAPPER}} .techza-dual-button-primary.effect-4::before,
                            {{WRAPPER}} .techza-dual-button-primary.effect-6::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_primary_button_normal_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-primary' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_primary_button_normal_bg',
            [
                'label'     => esc_html__( 'Background Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#4243DC',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-primary.effect-1' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-2' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-3' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-4' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-5' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-6' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'techza_dual_button_primary_button_normal_border',
                'selector' => '{{WRAPPER}} .techza-dual-button-primary',
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'techza_dual_button_primary_button_normal_box_shadow',
                'selector' => '{{WRAPPER}} .techza-dual-button-primary',
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'techza_dual_button_primary_button_hover', ['label' => esc_html__( 'Hover', 'techza' )] );
        $this->add_control(
            'techza_dual_button_primary_button_animation',
            [
                'label'   => esc_html__( 'Hover Effect', 'techza' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'effect-5',
                'options' => [
                    'effect-1' => __( 'Effect 1', 'techza' ),
                    'effect-2' => __( 'Effect 2', 'techza' ),
                    'effect-3' => __( 'Effect 3', 'techza' ),
                    'effect-4' => __( 'Effect 4', 'techza' ),
                    'effect-5' => __( 'Effect 5', 'techza' ),
                    'effect-6' => __( 'Effect 6', 'techza' ),
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_primary_button_hover_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-primary:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_primary_button_hover_bg',
            [
                'label'     => esc_html__( 'Background Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#5543dc',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-primary.effect-1::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-2::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-3::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-4::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-5:hover'   => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-primary.effect-6::before' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'techza_dual_button_primary_button_hover_border',
                'selector' => '{{WRAPPER}} .techza-dual-button-primary:hover',
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'techza_dual_button_primary_button_hover_box_shadow',
                'selector' => '{{WRAPPER}} .techza-dual-button-primary:hover',
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        /*
         * Finest Base Dual Button secondary Button Style
         */
        $this->start_controls_section(
            'techza_container_secondary_button_style',
            [
                'label'     => esc_html__( 'Secondary Button', 'techza' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'enable_secondary_btn[value]' => 'yes',
                ],
            ]
        );
        $this->start_controls_tabs( 'techza_dual_button_secondary_button_tabs' );
        $this->start_controls_tab( 'techza_dual_button_secondary_button_noemal', ['label' => esc_html__( 'Normal', 'techza' )] );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'techza_container_secondary_button_typography',
                'selector' => '{{WRAPPER}} .techza-dual-button-secondary span',
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_secondary_button_icon_margin',
            [
                'label'      => __( 'Icon Space', 'techza' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 3,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 10,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-secondary .techza-icon-pos-left i'  => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .techza-dual-button-secondary .techza-icon-pos-right i' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'techza_dual_button_secondary_button_icon[value]!' => '',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_secondary_button_normal_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-secondary' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_secondary_button_normal_bg',
            [
                'label'     => esc_html__( 'Background Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#EF2469',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-1' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-2' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-3' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-4' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-5' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-6' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'techza_dual_button_secondary_button_normal_border',
                'selector' => '{{WRAPPER}} .techza-dual-button-secondary',
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'techza_dual_button_secondary_button_normal_box_shadow',
                'selector' => '{{WRAPPER}} .techza-dual-button-secondary',
            ]
        );
        $this->add_responsive_control(
            'techza_container_secondary_button_padding',
            [
                'label'      => __( 'Padding', 'techza' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'default'    => [
                    'top'      => '',
                    'right'    => '',
                    'bottom'   => '',
                    'left'     => '',
                    'unit'     => 'px',
                    'isLinked' => false,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-secondary' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_container_secondary_button_margin',
            [
                'label'      => __( 'Margin', 'techza' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'default'    => [
                    'top'      => '',
                    'right'    => '',
                    'bottom'   => '',
                    'left'     => '',
                    'unit'     => 'px',
                    'isLinked' => false,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-secondary' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'techza_dual_button_secondary_button_radius',
            [
                'label'      => __( 'Border radius', 'techza' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'default'    => [
                    'top'    => '3',
                    'right'  => '3',
                    'bottom' => '3',
                    'left'   => '3',
                    'unit'   => 'px',
                ],
                'selectors'  => [
                    '{{WRAPPER}} .techza-dual-button-secondary, {{WRAPPER}} .techza-dual-button-secondary.effect-1::before, {{WRAPPER}} .techza-dual-button-secondary.effect-2::before, {{WRAPPER}} .techza-dual-button-secondary.effect-3::before, {{WRAPPER}} .techza-dual-button-secondary.effect-4::before, {{WRAPPER}} .techza-dual-button-secondary.effect-6::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'techza_dual_button_secondary_button_hover', ['label' => esc_html__( 'Hover', 'techza' )] );
        $this->add_control(
            'techza_dual_button_secondary_button_animation',
            [
                'label'   => esc_html__( 'Hover Effect', 'techza' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'effect-5',
                'options' => [
                    'effect-1' => __( 'Effect 1', 'techza' ),
                    'effect-2' => __( 'Effect 2', 'techza' ),
                    'effect-3' => __( 'Effect 3', 'techza' ),
                    'effect-4' => __( 'Effect 4', 'techza' ),
                    'effect-5' => __( 'Effect 5', 'techza' ),
                    'effect-6' => __( 'Effect 6', 'techza' ),
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_secondary_button_hover_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-secondary:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'techza_dual_button_secondary_button_hover_bg',
            [
                'label'     => esc_html__( 'Background Color', 'techza' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#EF2469',
                'selectors' => [
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-1::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-2::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-3::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-4::before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-5:hover'   => 'background: {{VALUE}};',
                    '{{WRAPPER}} .techza-dual-button-secondary.effect-6::before' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'techza_dual_button_secondary_button_hover_border',
                'selector' => '{{WRAPPER}} .techza-dual-button-secondary:hover',
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'techza_dual_button_secondary_button_hover_box_shadow',
                'selector' => '{{WRAPPER}} .techza-dual-button-secondary:hover',
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    /**

     * Render oEmbed widget output on the frontend.

     *

     * Written in PHP and used to generate the final HTML.

     *

     * @since 1.0.0

     * @access protected

     */

    protected function render() {

        $popular_post_key = [];

        $popular_meta_value_num = [];

        $settings = $this->get_settings_for_display();

        if ( 'yes' == $settings['use_main_menu'] ) {

            $args = [

                'theme_location'  => 'main-menu',

                'menu_class'      => 'navbar-nav',

                'menu_id'         => 'navbar-nav',

                'container_class' => 'techza-menu-container',

            ];

        } else {

            $args = [

                // 'theme_location'        => 'main-menu',

                'menu'            => $settings['primary_menu'],

                'menu_class'      => 'navbar-nav',

                'menu_id'         => 'navbar-nav',

                'container_class' => 'techza-menu-container',

            ];

        }

        ?>


        <div class="techza-main-menu-wrap navbar <?php printf( 'menu-style-%s  megamenu-width-%s', esc_attr( $settings['menu_style'] ), esc_attr( $settings['megamenu_width_type'] ) )?>">
            <button class="navbar-toggler open-menu" type="button" data-toggle="navbarToggler" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon">
                    <?php Icons_Manager::render_icon( $settings['trigger_open_icon'], ['aria-hidden' => 'true'] );?>
                </span>

                <?php if ( !empty( $settings['trigger_label'] ) ) {
            printf( '<span cla ss="trigger-label"> %s </span>', $settings['trigger_label'] ? $settings['trigger_label'] : '' );

        }?>

            </button>
            <!-- end of Nav toggler -->
            <div class="navbar-inner">

                <div class="site-branding mobile-version <?php echo esc_attr( $has_site_logo ) ?> has-site-logo">



                    <a href="<?php echo esc_url( home_url() ) ?>">


                        <?php
if ( 'custom' == $settings['logo_type'] && $settings['image']['url'] ) {
            echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
        } else {
            echo $this->techza_get_mobile_version_logo( $settings['logo_type'] );
        }
        ?>
                    </a>
                </div><!-- .site-branding -->

                <div class="techza-mobile-menu"></div>
                <button class="navbar-toggler close-menu" type="button" data-toggle="navbarToggler" aria-label="Toggle navigation">

                    <?php if ( !empty( $settings['trigger_label'] ) ) {
            printf( '<span cla ss="trigger-label"> %s </span>', $settings['trigger_label'] ? $settings['trigger_label'] : '' );

        }?>
                    <span class="navbar-toggler-icon close">
                    <?php Icons_Manager::render_icon( $settings['trigger_close_icon'], ['aria-hidden' => 'true'] );?>

                    </span>

                </button>

                <nav id="site-navigation" class="main-navigation ">

                    <?php wp_nav_menu( $args );?>

                </nav><!-- #site-navigation -->

                <?php if ( 'yes' == $settings['enable_primary_btn'] || 'yes' == $settings['enable_secondary_btn'] ): ?>
                    <div class="techza-header-buttons">
                        <?php $this->techza_dual_buttons()?>
                    </div>
                <?php endif;?>




                <?php if ( 'yes' == $settings['show_infos'] ): ?>

                       <div class="techza-header-infos">

                           <?php

        foreach ( $settings['header_infos'] as $info ):

            $target = $info['info_url']['is_external'] ? ' target="_blank"' : '';

            $nofollow = $info['info_url']['nofollow'] ? ' rel="nofollow"' : '';

            $info_url_attr = $info['info_url']['url'] ? "href='{$info['info_url']['url']}' {$target} {$nofollow}" : '';

            $info_tag = !empty( $info['info_url']['url'] ) ? 'a' : 'div';

            printf(

                '<%1$s %2$s class="header-info">

	                                <span> %3$s </span>

	                                <h3>  %4$s</h3>

	                                </%1$s>',

                $info_tag,

                $info_url_attr,

                esc_html( $info['info_title'] ),

                esc_html( $info['info_content'] )

            )

            ?>

			                            <?php endforeach;?>

                       </div>

                <?php endif;?>
            </div>

        </div>

<?php
}

// custom logo mobile
    public function techza_get_mobile_version_logo( $logo_type = 'dark' ) {
        $logo = '';
        $techza = get_option( 'techza' );
        $logo_url = '';

        if ( 'dark' == $logo_type && isset( $techza['logo']['url'] ) ) {

            $logo_url = esc_url( $techza['logo']['url'] );
            $logo = '<img src="' . esc_url( $logo_url ) . '" alt="' . esc_attr( get_bloginfo( 'title' ) ) . '" class="navbar-brand__regular dark-logo">';

        } else if ( 'white' == $logo_type && isset( $techza['white_logo']['url'] ) ) {

            $logo_url = esc_url( $techza['white_logo']['url'] );
            $logo = '<img src="' . esc_url( $logo_url ) . '" alt="' . esc_attr( get_bloginfo( 'title' ) ) . '" class="navbar-brand__regular white-logo">';

        } else {
            if ( has_custom_logo() ) {

                $core_logo_id = get_theme_mod( 'custom_logo' );
                $logo_url = wp_get_attachment_image_src( $core_logo_id, 'full' );
                $logo = '<img src="' . esc_url( $logo_url[0] ) . '" alt="' . esc_attr( get_bloginfo( 'title' ) ) . '" class="navbar-brand__regular">';

            } else {

                $logo = '<h1 class="navbar-brand__regular">' . get_bloginfo( 'name' ) . '</h1>';

            }

        }

        return $logo;
    }

    public function techza_dual_buttons() {
        $settings = $this->get_settings_for_display();
        $secondary_btn_icon_pos = $settings['techza_dual_button_secondary_button_icon_position'];
        $primary_btn_icon_pos = $settings['techza_dual_button_primary_button_icon_position'];

        $this->add_render_attribute(
            'techza_dual_button_primary_button_url',
            [
                'class' => [
                    'techza-dual-button-primary techza-dual-button-action',
                    esc_attr( $settings['techza_dual_button_primary_button_animation'] ),
                ],
            ]
        );
        $this->add_render_attribute(
            'techza_dual_button_secondary_button_url',
            [
                'class' => [
                    'techza-dual-button-secondary techza-dual-button-action',
                    esc_attr( $settings['techza_dual_button_secondary_button_animation'] ),
                ],
            ]
        );
        if ( isset( $settings['techza_dual_button_primary_button_url']['url'] ) ) {
            $this->add_render_attribute( 'techza_dual_button_primary_button_url', 'href', esc_url( $settings['techza_dual_button_primary_button_url']['url'] ) );
            if ( isset( $settings['techza_dual_button_primary_button_url']['is_external'] ) ) {
                $this->add_render_attribute( 'techza_dual_button_primary_button_url', 'target', '_blank' );
            }
            if ( isset( $settings['techza_dual_button_primary_button_url']['nofollow'] ) ) {
                $this->add_render_attribute( 'techza_dual_button_primary_button_url', 'rel', 'nofollow' );
            }
        }
        if ( isset( $settings['techza_dual_button_secondary_button_url']['url'] ) ) {
            $this->add_render_attribute( 'techza_dual_button_secondary_button_url', 'href', esc_url( $settings['techza_dual_button_secondary_button_url']['url'] ) );
            if ( isset( $settings['techza_dual_button_secondary_button_url']['is_external'] ) ) {
                $this->add_render_attribute( 'techza_dual_button_secondary_button_url', 'target', '_blank' );
            }
            if ( isset( $settings['techza_dual_button_secondary_button_url']['nofollow'] ) ) {
                $this->add_render_attribute( 'techza_dual_button_secondary_button_url', 'rel', 'nofollow' );
            }
        }
        $this->add_inline_editing_attributes( 'techza_dual_button_primary_button_text', 'none' );
        $this->add_inline_editing_attributes( 'techza_dual_button_secondary_button_text', 'none' );
        ?>
        <div <?php echo $this->get_render_attribute_string( 'techza_dual_button' ); ?>>
            <div class="techza-dual-button-wrapper">
                <a <?php echo $this->get_render_attribute_string( 'techza_dual_button_primary_button_url' ); ?>>
                    <span class="<?php echo esc_attr( $primary_btn_icon_pos ); ?>">
                        <?php
if ( 'techza-icon-pos-left' === $primary_btn_icon_pos && !empty( $settings['techza_dual_button_primary_button_icon']['value'] ) ) {
            Icons_Manager::render_icon( $settings['techza_dual_button_primary_button_icon'] );
        }
        ?>
                        <span <?php echo $this->get_render_attribute_string( 'techza_dual_button_primary_button_text' ); ?>>
                            <?php echo esc_html( $settings['techza_dual_button_primary_button_text'] ); ?>
                        </span>
                        <?php
if ( 'techza-icon-pos-right' === $primary_btn_icon_pos && !empty( $settings['techza_dual_button_primary_button_icon']['value'] ) ) {
            Icons_Manager::render_icon( $settings['techza_dual_button_primary_button_icon'] );
        }
        ?>
                    </span>
                </a>
                <a <?php echo $this->get_render_attribute_string( 'techza_dual_button_secondary_button_url' ); ?>>
                    <span class="<?php echo esc_attr( $secondary_btn_icon_pos ); ?>">
                        <?php
if ( 'techza-icon-pos-left' === $secondary_btn_icon_pos && !empty( $settings['techza_dual_button_secondary_button_icon']['value'] ) ) {
            Icons_Manager::render_icon( $settings['techza_dual_button_secondary_button_icon'] );
        }
        ?>
                        <span <?php echo $this->get_render_attribute_string( 'techza_dual_button_secondary_button_text' ); ?>>
                            <?php echo esc_html( $settings['techza_dual_button_secondary_button_text'] ); ?>
                        </span>
                        <?php
if ( 'techza-icon-pos-right' === $secondary_btn_icon_pos && !empty( $settings['techza_dual_button_secondary_button_icon']['value'] ) ) {
            Icons_Manager::render_icon( $settings['techza_dual_button_secondary_button_icon'] );
        }
        ?>
                    </span>
                </a>
            </div>
        </div>

<?php

    }

}

$widgets_manager->register_widget_type( new \Techza\Widgets\Main_Menu() );